{ config, pkgs, ... }:

{
  boot.loader = {
    timeout = 1;
    efi.canTouchEfiVariables = true;

    grub = {
      efiSupport = true;
      device = "nodev";
      configurationLimit = 5;
    };
  };

  powerManagement.enable = true;

  services.xserver = {
    enable = true;
    windowManager.i3.enable = true;
    layout = "de";

    libinput = {
      enable = true;
      touchpad = {
        horizontalScrolling = false;
	naturalScrolling = true;
      };
    };

    displayManager = {
      defaultSession = "none+i3";
      autoLogin = {
        enable = true;
	user = "mandlm";
      };
    };
  };

  time.timeZone = "Europe/Berlin";
  services.timesyncd.enable = true;

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "de-latin1-nodeadkeys";
  };

  fonts.fonts = with pkgs; [
    (nerdfonts.override { fonts = [ "DejaVuSansMono" ]; })
    font-awesome
  ];

  hardware.pulseaudio.enable = true;
  
  programs.gnupg.agent = {
    enable = true;
  };

  environment.systemPackages = with pkgs; [
    neovim
    git
  ];

  services.openssh.enable = true;

  nix = {
    package = pkgs.nixFlakes;
    extraOptions = "experimental-features = nix-command flakes";
  };

  system.stateVersion = "22.05";
}

