{
  inputs = {
    nixpkgs.url = github:NixOS/nixpkgs/nixos-22.05;
    nixpkgs-unstable.url = github:NixOS/nixpkgs/nixos-unstable;

    home-manager = {
      url = github:nix-community/home-manager/release-22.05;
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = inputs @ { self, nixpkgs, home-manager, ... }: 
    let 
      user = "mandlm";
    in 
    {
      nixosConfigurations.nixos-vm = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = inputs;
        modules = [
	  ./configuration.nix
	  ./users.nix
	  ./machines/nixos-vm/configuration.nix 
	  ./machines/nixos-vm/hardware-configuration.nix 

	  home-manager.nixosModules.home-manager {
	    home-manager.useGlobalPkgs = true;
	    home-manager.useUserPackages = true;
	    home-manager.extraSpecialArgs = { inherit user; };
	    home-manager.users.${user} = {
	      imports = [ ./home-${user}.nix ];
	    };
	  }
	];
      };

      nixosConfigurations.apache = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = inputs;
        modules = [
	  ./configuration.nix
	  ./users.nix
	  ./machines/apache/configuration.nix 
	  ./machines/apache/hardware-configuration.nix 

	  home-manager.nixosModules.home-manager {
	    home-manager.useGlobalPkgs = true;
	    home-manager.useUserPackages = true;
	    home-manager.extraSpecialArgs = { inherit user; };
	    home-manager.users.${user} = {
	      imports = [ ./home-${user}.nix ];
	    };
	  }
	];
      };
    };
}
